==> haskell-protolude-0.3.5-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-protolude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 protolude
version:              0.3.5
visibility:           public
id:                   protolude-0.3.5-BvyeYrbThGk44kJ4wmFVOp
key:                  protolude-0.3.5-BvyeYrbThGk44kJ4wmFVOp
license:              MIT
copyright:            2016-2022 Stephen Diehl
maintainer:           adamwespiser@gmail.com, stephen.m.diehl@gmail.com
author:               Stephen Diehl
homepage:             https://github.com/sdiehl/protolude
synopsis:             A small prelude.
description:          A sensible set of defaults for writing custom Preludes.
category:             Prelude
abi:                  99780cc2fd5934f1a79a9c46950b1d9d
exposed:              True
exposed-modules:
    Protolude Protolude.Applicative Protolude.Base Protolude.Bifunctor
    Protolude.Bool Protolude.CallStack Protolude.Conv
    Protolude.ConvertText Protolude.Debug Protolude.Either
    Protolude.Error Protolude.Exceptions Protolude.Functor
    Protolude.List Protolude.Monad Protolude.Panic Protolude.Partial
    Protolude.Safe Protolude.Semiring Protolude.Show Protolude.Unsafe

import-dirs:          /usr/lib/ghc-9.4.8/site-local/protolude-0.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/protolude-0.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/protolude-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-protolude
hs-libraries:         HSprotolude-0.3.5-BvyeYrbThGk44kJ4wmFVOp
depends:
    array-0.5.4.0 async-2.2.5-H08LAofdMrZAVDKKqADI6w base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0 ghc-prim-0.9.1
    hashable-1.4.6.0-HNsjIjcKtfz4EPsBV3Crzv mtl-2.2.2 stm-2.5.1.0
    text-2.0.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html:         /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-protolude-0.3.5-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-protolude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 protolude
version:              0.3.5
visibility:           public
id:                   protolude-0.3.5-8s1pM0xA0FP32qOQYBnPWA
key:                  protolude-0.3.5-8s1pM0xA0FP32qOQYBnPWA
license:              MIT
copyright:            2016-2022 Stephen Diehl
maintainer:           adamwespiser@gmail.com, stephen.m.diehl@gmail.com
author:               Stephen Diehl
homepage:             https://github.com/sdiehl/protolude
synopsis:             A small prelude.
description:          A sensible set of defaults for writing custom Preludes.
category:             Prelude
abi:                  d042aa3b599c315d55288f36cee40a86
exposed:              True
exposed-modules:
    Protolude Protolude.Applicative Protolude.Base Protolude.Bifunctor
    Protolude.Bool Protolude.CallStack Protolude.Conv
    Protolude.ConvertText Protolude.Debug Protolude.Either
    Protolude.Error Protolude.Exceptions Protolude.Functor
    Protolude.List Protolude.Monad Protolude.Panic Protolude.Partial
    Protolude.Safe Protolude.Semiring Protolude.Show Protolude.Unsafe

import-dirs:          /usr/lib/ghc-9.4.8/site-local/protolude-0.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/protolude-0.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/protolude-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-protolude
hs-libraries:         HSprotolude-0.3.5-8s1pM0xA0FP32qOQYBnPWA
depends:
    array-0.5.4.0 async-2.2.5-J9xl5BKgt0u6YsIOuQfrTS base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0 ghc-prim-0.9.1
    hashable-1.4.7.0-GgneweRn8eTKcMM4X3n956 mtl-2.2.2 stm-2.5.1.0
    text-2.0.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html:         /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
